@@ -2,7 +2,11 @@ mod asset_canister;
 mod content;
 mod content_encoder;
 mod convenience;
+mod operations;
 mod params;
+mod plumbing;
 mod sync;
+mod upload;
 
 pub use sync::sync;
+pub use upload::upload;
